import bleach
from flask import Blueprint, current_app as app, request, jsonify

from opentakserver.extensions import logger

citrap_api_blueprint = Blueprint("citrap_api_blueprint", __name__)


@citrap_api_blueprint.route('/Marti/api/missions/citrap/subscription', methods=['PUT'])
def citrap_subscription():
    uid = bleach.clean(request.args.get('uid'))
    response = {
        'version': 3, 'type': 'com.bbn.marti.sync.model.MissionSubscription',
        'data': {

        }
    }
    return '', 201


@citrap_api_blueprint.route('/Marti/api/citrap')
def citrap():
    return jsonify([])


@citrap_api_blueprint.route('/Marti/api/citrap', methods=["POST", "PUT"])
def post_citrap():
    logger.info(request.data)
    logger.info(request.headers)
    f = open("/home/administrator/ots/report.zip", "wb")
    f.write(request.data)
    f.close()
    return jsonify([])



import datetime
import time
from dataclasses import dataclass
from flask import request, current_app as app

from opentakserver.functions import iso8601_string_from_datetime
from opentakserver.extensions import db, logger
from sqlalchemy import Integer, String, Boolean, JSON, DateTime, ForeignKey
from sqlalchemy.orm import Mapped, mapped_column, relationship

from opentakserver.models.MissionRole import MissionRole


@dataclass
class Report(db.Model):
    __tablename__ = "reports"

    id: Mapped[str] = mapped_column(String(255), primary_key=True)
    type: Mapped[str] = mapped_column(String(255), nullable=True)
    user_callsign: Mapped[str] = mapped_column(String(255), ForeignKey("user.username", ondelete="CASCADE"), nullable=True)
    user_description: Mapped[str] = mapped_column(String(255), nullable=True)
    date_time: Mapped[DateTime] = mapped_column(DateTime, nullable=True)
    date_time_description: Mapped[str] = mapped_column(String(255), nullable=True)
    : Mapped[str] = mapped_column(String(255), nullable=True)
